{
  inputs,
  config,
  pkgs,
  self,
  ...
}:

{
  imports = [
    ../../nix-os/core.nix
    ../../nix-os/core-desktop.nix
    ../../nix-os/nvidia.nix
    ../../nix-os/docker.nix
    ../../nix-os/razer.nix
    ../../nix-os/desktopManagers/cosmic.nix
    ../../nix-os/displayManagers/cosmic-greeter.nix
    ../../nix-os/shell.nix
    ../../nix-os/virtualization.nix
    ../../nix-os/polkit/disable-shutdown.nix
    ../../nix-os/locale.nix
    ../../nix-os/adb.nix
    ../../nix-os/account.nix
    ../../nix-os/services/nix-binary-cache.nix
    ../../nix-os/udev.nix
    ../../nix-os/gnupg.nix

    "${inputs.nixos-vscode-server}"
  ];

  config = {
    boot.loader.systemd-boot.enable = true;
    boot.loader.efi.canTouchEfiVariables = true;

    networking.hostName = "wroclaw-main";

    services.printing.drivers = with pkgs; [
      hplip
    ];

    nixpkgs.overlays = [
      self.overlays.cosmicPackages
    ];
    nixpkgs.config = {
      cudaSupport = true;
    };

    # nixos-vscode-server module needs this
    programs.nix-ld.enable = true;
    services.vscode-server = {
      enable = true;
      extraRuntimeDependencies = with pkgs; [
        docker
      ];
    };

    services.pipewire.wireplumber.configPackages = [(
      pkgs.stdenvNoCC.mkDerivation {
        name = "wireplumber-config";
        src = ./wireplumber;
        phases = [ "installPhase" ];
        installPhase = ''
          mkdir -p $out/share/wireplumber/wireplumber.conf.d
          cp -r $src/* $out/share/wireplumber/wireplumber.conf.d
        '';
      }
    )];

    services.printing.startWhenNeeded = false;

    # rgb control for razer, graphics card and motherboard
    hardware.i2c.enable = true;
    services.hardware.openrgb.enable = true;

    services.ollama = {
      enable = true;
      port = 1434;
      acceleration = "cuda";
      package = pkgs.unstable.ollama;
      host = "0.0.0.0";
    };
    environment.sessionVariables = {
      OLLAMA_HOST = "127.0.0.1:${builtins.toString config.services.ollama.port}";
    };

    system.stateVersion = "23.05";
  };
}
